Index: chrome/common/child_process_logging_win.cc |
diff --git a/chrome/common/child_process_logging_win.cc b/chrome/common/child_process_logging_win.cc |
index 1befb33b23a2eb971ddecee0e1c277a40b51e471..b849734250a83d636f701de590117c50bf41544a 100644 |
--- a/chrome/common/child_process_logging_win.cc |
+++ b/chrome/common/child_process_logging_win.cc |
@@ -65,12 +65,13 @@ void Init() { |
base::debug::SetCrashKeyReportingFunctions( |
&SetCrashKeyValueTrampoline, &ClearCrashKeyValueTrampoline); |
- // This would be handled by BreakpadClient::SetClientID(), but because of the |
- // aforementioned issue, crash keys aren't ready yet at the time of Breakpad |
- // initialization. |
- std::string client_id; |
- if (GoogleUpdateSettings::GetMetricsId(&client_id)) |
- base::debug::SetCrashKeyValue(crash_keys::kClientID, client_id); |
+ // This would be handled by BreakpadClient::SetCrashClientIdFromGUID(), but |
+ // because of the aforementioned issue, crash keys aren't ready yet at the |
+ // time of Breakpad initialization, load the client id backed up in Google |
+ // Update settings instead. |
+ std::string client_guid; |
+ if (GoogleUpdateSettings::LoadMetricsClientId(&client_guid)) |
+ crash_keys::SetCrashClientIdFromGUID(client_guid); |
} |
} // namespace child_process_logging |